@@ -35,7 +35,7 @@ to a BIND readable text form.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.5'
+__version__ = '0.6'
 
 
 import os
@@ -101,12 +101,14 @@ class BindTreeExport(object):
   def ExportAllBindTrees(self):
     """Exports bind trees to files"""
     self.db_instance.StartTransaction()
-    self.db_instance.LockDb()
     try:
-      data = self.GetRawData()
+      self.db_instance.LockDb()
+      try:
+        data = self.GetRawData()
+      finally:
+        self.db_instance.UnlockDb()
     finally:
-      self.db_instance.UnlockDb()
-      self.db_instance.CommitTransaction()
+        self.db_instance.EndTransaction()
     cooked_data = self.CookData(data)
 
     record_arguments = data['record_arguments']
